==> benno-web-2.4.1.tgz: srv/benno/bennoweb/htdocs/model/MailObject.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


class MailObject
{

    var $id;        // searchId
    var $permaId;   // id to access email: base64(<box>:<bennoId>@<archive>)
    var $from;
    var $to;
    var $cc;
    var $bcc;
    var $subject;
    var $date;
    var $time;
    var $size;
    var $body;
    var $bodytype;
    var $isError;
    var $errorMsg;


    function MailObject($id,$permaId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
    {
        $this->id       = $id; 
        $this->permaId  = $permaId;
        $this->from     = $from;
        $this->to       = $to;
        $this->cc       = $cc;
        $this->bcc      = $bcc;
        $this->subject  = $subject;
        $this->date     = $date;
        $this->time     = $time;
        $this->size     = $size;
        $this->body     = $body;
        $this->attachments = $attachments;
        $this->bodytype = 'text/plain';
        $this->isError  = false;
        $this->errorMsg = '';
    }


    function setBody($content,$content_type)
    {
        if ($content_type = 'text/plain') {
            $this->body = nl2br($content);
        }
        else {
            $this->body = $content;
        }
    }

    function setDate($date) { $this->date = $date; }


    function setTime($time) { $this->time = $time; }


    function setError($msg_sym)
    {
        global $App;
        $this->isError  = true;
        $this->errorMsg = $App->getMsg($msg_sym);
    }

}
?>

==> benno-web-2.4.6.tgz: srv/benno/bennoweb/htdocs/model/MailObject.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


class MailObject
{

    var $id;        // searchId
    var $permaId;   // id to access email: base64(<box>:<bennoId>@<archive>)
    var $from;
    var $to;
    var $cc;
    var $bcc;
    var $subject;
    var $date;
    var $time;
    var $size;
    var $body;
    var $bodytype;
    var $isError;
    var $errorMsg;


    function MailObject($id,$permaId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
    {
        $this->id       = $id; 
        $this->permaId  = $permaId;
        $this->from     = $from;
        $this->to       = $to;
        $this->cc       = $cc;
        $this->bcc      = $bcc;
        $this->subject  = $subject;
        $this->date     = $date;
        $this->time     = $time;
        $this->size     = $size;
        $this->body     = $body;
        $this->attachments = $attachments;
        $this->bodytype = 'text/plain';
        $this->isError  = false;
        $this->errorMsg = '';
    }


    function setBody($content,$content_type)
    {
        if ($content_type == 'text/plain') {
            $this->body = nl2br($content);
        }
        else {
            $this->bodytype = 'text/html';
            $this->body = $content;
        }
    }

    function setDate($date) { $this->date = $date; }


    function setTime($time) { $this->time = $time; }


    function setError($msg_sym)
    {
        global $App;
        $this->isError  = true;
        $this->errorMsg = $App->getMsg($msg_sym);
    }

}
?>
